==> psi-plugins-debug-1.5-3-x86_64.pkg.tar.zst: usr/src/debug/psi-plugins/plugins-1.5/generic/icqdieplugin/.rcc/qrc_resources.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.15.14
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /build/psi-plugins/src/plugins-1.5/generic/icqdieplugin/icqdie.png
  0x0,0x0,0x3,0xfa,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x10,0x0,0x0,0x0,0x10,0x8,0x6,0x0,0x0,0x0,0x1f,0xf3,0xff,0x61,
  0x0,0x0,0x0,0x1,0x73,0x52,0x47,0x42,0x0,0xae,0xce,0x1c,0xe9,0x0,0x0,0x0,
  0x6,0x62,0x4b,0x47,0x44,0x0,0xff,0x0,0xff,0x0,0xff,0xa0,0xbd,0xa7,0x93,0x0,
  0x0,0x0,0x9,0x70,0x48,0x59,0x73,0x0,0x0,0xb,0x13,0x0,0x0,0xb,0x13,0x1,
  0x0,0x9a,0x9c,0x18,0x0,0x0,0x0,0x7,0x74,0x49,0x4d,0x45,0x7,0xda,0x4,0xd,
  0x8,0x26,0x15,0xd8,0x8b,0xdd,0x83,0x0,0x0,0x3,0x7a,0x49,0x44,0x41,0x54,0x38,
  0xcb,0x35,0x93,0xff,0x4f,0xd4,0x75,0x1c,0xc7,0x9f,0xaf,0xf7,0x7d,0x80,0xe3,0x2e,
  0xb8,0xe3,0x38,0x49,0xe,0x4e,0x4f,0x2e,0xc0,0x4b,0x5b,0x7e,0x9,0x73,0x6b,0x2e,
  0x1b,0x53,0xa0,0xe,0x56,0x69,0x6e,0xc1,0xd6,0x72,0x58,0xc0,0x58,0x3f,0x24,0x1,
  0xae,0x35,0xb3,0xb5,0xba,0xb4,0xb5,0xb5,0x5c,0x1b,0xd3,0xe9,0x86,0x2b,0x1d,0xe5,
  0xf,0x4d,0x6a,0xb5,0x65,0xce,0x46,0x26,0x60,0xb5,0x99,0xa6,0x19,0x88,0x22,0xc4,
  0x71,0x19,0x77,0x17,0x70,0xc0,0x1d,0xf7,0x79,0x3f,0xfb,0x1,0xfd,0x3,0x1e,0xcf,
  0xc7,0x2f,0x8f,0xa7,0x90,0xd4,0x24,0x5,0x0,0x1,0x40,0x44,0xb0,0xb8,0xb0,0x88,
  0xc,0x6b,0x6,0x0,0x20,0x3c,0x11,0x46,0x77,0xf7,0x9,0x41,0x9a,0xac,0x6f,0x68,
  0xc0,0x8a,0x12,0x2f,0xb4,0x26,0x44,0x0,0x0,0x50,0x24,0x71,0xf,0xa6,0x88,0xb0,
  0xff,0x62,0x3f,0xea,0x76,0xd5,0xb2,0xa3,0xb3,0x9d,0xb,0x89,0x24,0xdf,0x3c,0xb0,
  0xf,0xf1,0xfc,0x31,0x5e,0x72,0xf5,0xb2,0xa6,0x79,0x2b,0xc3,0xa3,0x11,0x28,0x25,
  0xbc,0xcf,0xa8,0xfb,0x56,0x11,0x51,0x0,0x54,0xe8,0xe3,0xf7,0xa4,0xf1,0xe0,0x4e,
  0x65,0xf,0x40,0xd5,0x54,0x3f,0xa3,0xec,0x2b,0x32,0xb0,0xe3,0xd5,0x2a,0x2c,0xaf,
  0xb6,0xa8,0x6b,0xd6,0x11,0xf5,0xfd,0x37,0xe7,0xe4,0x9e,0x58,0x1,0x50,0x86,0x88,
  0x20,0x3e,0x35,0x8d,0x2f,0x7a,0x7a,0x50,0xea,0x2f,0xa5,0xc7,0x53,0x84,0x92,0x95,
  0x7e,0xe4,0x17,0x39,0x70,0xf4,0xdd,0x53,0xb2,0x12,0xe,0x9c,0x1d,0xed,0xc5,0x4f,
  0xe7,0x7,0xe1,0x59,0x70,0xb0,0xcc,0x5f,0xe,0xa4,0x1,0x65,0x28,0x50,0x13,0x96,
  0xd6,0x96,0xd6,0xb7,0x5b,0xf6,0xbe,0x42,0x47,0x81,0x5d,0x46,0xc7,0xee,0xa0,0xfb,
  0x70,0xb7,0xc4,0x52,0x71,0x54,0xd4,0xac,0x13,0x6b,0xdf,0x10,0x36,0x5b,0x52,0x52,
  0x38,0x12,0xc1,0xaa,0x81,0x5c,0xc9,0xbd,0xb5,0xc,0x3f,0xcc,0xf,0xc8,0xc1,0xae,
  0x43,0xf0,0xe6,0x78,0xa5,0x6c,0x75,0x39,0x8c,0x2f,0x4f,0x9e,0xc6,0xd8,0xea,0x4b,
  0x68,0x7a,0xbd,0x16,0x3e,0x3c,0x8a,0x6c,0x1f,0xd0,0xd5,0x71,0x4,0x2d,0x49,0xa0,
  0xd3,0x9a,0x5,0x26,0xb2,0x80,0x21,0x2d,0xc8,0x74,0xc0,0xf2,0xb8,0x45,0x7e,0x2d,
  0x99,0x43,0xeb,0x23,0xc3,0x68,0xb,0xb5,0xa3,0xba,0x2a,0x8,0x43,0x59,0xc,0xdc,
  0x18,0x19,0x93,0xfd,0x3f,0xbe,0x86,0x65,0x89,0x62,0x6c,0xc,0x6c,0xc1,0xa7,0xc1,
  0x80,0xf8,0x6,0x6f,0x60,0x2e,0xd3,0xc0,0xef,0xce,0x59,0xf4,0xf4,0xff,0xc3,0xa6,
  0xc7,0x8a,0xc4,0x7b,0xed,0x3f,0xac,0xb9,0x9e,0x87,0x4e,0x4f,0x99,0x5c,0xdd,0xf2,
  0x14,0x54,0x16,0x80,0x58,0x34,0xae,0x83,0xbb,0x82,0xa6,0xbb,0x2e,0x93,0xd9,0xcf,
  0x81,0x4f,0xd7,0x7a,0x38,0xbe,0xb6,0x94,0x23,0x6b,0x1f,0xe2,0xc2,0x85,0xcd,0x9c,
  0x1e,0x77,0xea,0xfd,0x7b,0x1e,0x34,0x7,0x1f,0xf6,0xf1,0xb6,0xd5,0xc6,0x5b,0x4e,
  0x7,0xc7,0xd7,0x95,0x73,0xfe,0xc2,0x45,0x92,0xa4,0x90,0xd4,0x0,0x64,0x67,0xdd,
  0x4b,0xbc,0xf2,0xed,0xd7,0x68,0x2b,0x76,0x4a,0xb5,0x99,0xc2,0x60,0xa9,0x15,0x81,
  0x43,0x37,0x19,0x1b,0x74,0xa1,0xe0,0x70,0xae,0xd8,0xfe,0x8e,0x22,0x1a,0xf0,0x62,
  0xda,0x9d,0xd,0xef,0x2f,0xa3,0xe8,0x2d,0x5f,0x8e,0xe0,0xf1,0x33,0x4b,0x3,0xa1,
  0xf7,0x43,0xe0,0x27,0x5d,0xac,0xf7,0xfa,0xa1,0x23,0x37,0x95,0x61,0x33,0xb0,0x2f,
  0x3e,0xc7,0xac,0x8d,0x64,0x67,0xd8,0xa9,0x9c,0xb1,0x59,0x44,0xf2,0x6c,0x38,0xdd,
  0x55,0xac,0xed,0x97,0xa7,0xe5,0xc5,0x8f,0xe2,0x72,0x34,0x67,0x92,0x52,0xbd,0x97,
  0x86,0x6,0x70,0xb9,0xaf,0xf,0x55,0x91,0x3b,0xea,0xaf,0x58,0x1c,0x13,0x85,0xe,
  0x6c,0xcb,0xb3,0xe1,0xe5,0xd,0x2b,0xc4,0x99,0xd4,0x52,0x60,0x8d,0x62,0xbc,0x28,
  0x1f,0x4d,0xb7,0x27,0x31,0x1c,0x1a,0x52,0x6f,0xd8,0x57,0xc1,0xe2,0xca,0x45,0x2,
  0xe,0x71,0x66,0x18,0x62,0x28,0x0,0x1d,0x1f,0x84,0xd0,0x11,0x9,0xc3,0x6d,0xb5,
  0x31,0x19,0x9d,0xc1,0x56,0x77,0x9e,0x54,0xb8,0xdc,0x58,0xbc,0x1b,0xc7,0x1f,0x54,
  0xf8,0xea,0x80,0x8d,0x33,0xe7,0x93,0xb2,0xe9,0x58,0x39,0x5f,0xa8,0x28,0x10,0xba,
  0x88,0xa9,0x19,0x1b,0xdb,0x76,0x37,0x42,0xb4,0xa9,0xb5,0x2c,0xa5,0xa9,0xae,0x5c,
  0x1f,0x65,0xdb,0xb1,0x7a,0x69,0xb4,0x67,0x61,0x7b,0xcc,0xd,0x8b,0x98,0x38,0x73,
  0x75,0x1c,0x3,0x4f,0xdc,0xa5,0x5f,0x3b,0xe4,0xf9,0x29,0x1f,0xb2,0xd3,0x26,0x86,
  0x72,0xfc,0x58,0xf3,0xd6,0x3b,0x70,0xb8,0x72,0x69,0x0,0x80,0x36,0x35,0x94,0x45,
  0x61,0xf2,0xcf,0x61,0xfc,0x36,0xf1,0x33,0x16,0x6a,0x5d,0xfc,0xf7,0xac,0x4f,0x76,
  0xe4,0x7,0x10,0xac,0x5c,0x8f,0xaa,0x94,0x16,0xa5,0x34,0xcc,0x7,0xe6,0x31,0x5b,
  0xbc,0x1,0xeb,0x77,0x37,0x33,0x3b,0xd7,0x2e,0xa6,0x69,0x2,0x4c,0x9b,0x5a,0xa7,
  0x4d,0x4d,0xad,0x99,0x4a,0xa4,0xf4,0xf6,0xba,0x6d,0xc4,0x26,0x68,0x94,0x81,0x7b,
  0x2a,0x9f,0x64,0xf8,0xf3,0xe3,0xfc,0xae,0xbd,0x99,0x1f,0x3e,0x5b,0xc9,0x73,0x5d,
  0x47,0x34,0x49,0x9a,0x8b,0x69,0x6d,0xa6,0x16,0xa9,0xd3,0xa6,0x16,0x9d,0xd6,0x1a,
  0x20,0x9,0x28,0x65,0x51,0x8c,0x47,0xe3,0x72,0xf2,0xb3,0x53,0x9c,0x4f,0x26,0xa4,
  0xbe,0xa1,0x1,0x85,0x9e,0xc2,0xa5,0xe7,0x11,0xa,0x2,0xea,0xb4,0x29,0xa2,0x14,
  0x41,0x2d,0x0,0xf8,0x3f,0xf3,0x74,0xa7,0xb4,0x1a,0x14,0x6f,0xd7,0x0,0x0,0x0,
  0x0,0x49,0x45,0x4e,0x44,0xae,0x42,0x60,0x82,
  
};

static const unsigned char qt_resource_name[] = {
  // icons
  0x0,0x5,
  0x0,0x6f,0xa6,0x53,
  0x0,0x69,
  0x0,0x63,0x0,0x6f,0x0,0x6e,0x0,0x73,
    // icqdie.png
  0x0,0xa,
  0xa,0xfd,0xa3,0xa7,
  0x0,0x69,
  0x0,0x63,0x0,0x71,0x0,0x64,0x0,0x69,0x0,0x65,0x0,0x2e,0x0,0x70,0x0,0x6e,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x90,0xad,0x1,0xb2,0x80,
  // :/icons
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x90,0xad,0x1,0xb2,0x80,
  // :/icons/icqdie.png
  0x0,0x0,0x0,0x10,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x90,0xad,0x1,0xb2,0x80,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_resources)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_resources)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_resources)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_resources)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_resources)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_resources)(); }
   } dummy;
}

==> psi-plugins-debug-1.5-3.1-x86_64.pkg.tar.zst: usr/src/debug/psi-plugins/plugins-1.5/generic/icqdieplugin/.rcc/qrc_resources.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.15.14
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /startdir/src/plugins-1.5/generic/icqdieplugin/icqdie.png
  0x0,0x0,0x3,0xfa,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x10,0x0,0x0,0x0,0x10,0x8,0x6,0x0,0x0,0x0,0x1f,0xf3,0xff,0x61,
  0x0,0x0,0x0,0x1,0x73,0x52,0x47,0x42,0x0,0xae,0xce,0x1c,0xe9,0x0,0x0,0x0,
  0x6,0x62,0x4b,0x47,0x44,0x0,0xff,0x0,0xff,0x0,0xff,0xa0,0xbd,0xa7,0x93,0x0,
  0x0,0x0,0x9,0x70,0x48,0x59,0x73,0x0,0x0,0xb,0x13,0x0,0x0,0xb,0x13,0x1,
  0x0,0x9a,0x9c,0x18,0x0,0x0,0x0,0x7,0x74,0x49,0x4d,0x45,0x7,0xda,0x4,0xd,
  0x8,0x26,0x15,0xd8,0x8b,0xdd,0x83,0x0,0x0,0x3,0x7a,0x49,0x44,0x41,0x54,0x38,
  0xcb,0x35,0x93,0xff,0x4f,0xd4,0x75,0x1c,0xc7,0x9f,0xaf,0xf7,0x7d,0x80,0xe3,0x2e,
  0xb8,0xe3,0x38,0x49,0xe,0x4e,0x4f,0x2e,0xc0,0x4b,0x5b,0x7e,0x9,0x73,0x6b,0x2e,
  0x1b,0x53,0xa0,0xe,0x56,0x69,0x6e,0xc1,0xd6,0x72,0x58,0xc0,0x58,0x3f,0x24,0x1,
  0xae,0x35,0xb3,0xb5,0xba,0xb4,0xb5,0xb5,0x5c,0x1b,0xd3,0xe9,0x86,0x2b,0x1d,0xe5,
  0xf,0x4d,0x6a,0xb5,0x65,0xce,0x46,0x26,0x60,0xb5,0x99,0xa6,0x19,0x88,0x22,0xc4,
  0x71,0x19,0x77,0x17,0x70,0xc0,0x1d,0xf7,0x79,0x3f,0xfb,0x1,0xfd,0x3,0x1e,0xcf,
  0xc7,0x2f,0x8f,0xa7,0x90,0xd4,0x24,0x5,0x0,0x1,0x40,0x44,0xb0,0xb8,0xb0,0x88,
  0xc,0x6b,0x6,0x0,0x20,0x3c,0x11,0x46,0x77,0xf7,0x9,0x41,0x9a,0xac,0x6f,0x68,
  0xc0,0x8a,0x12,0x2f,0xb4,0x26,0x44,0x0,0x0,0x50,0x24,0x71,0xf,0xa6,0x88,0xb0,
  0xff,0x62,0x3f,0xea,0x76,0xd5,0xb2,0xa3,0xb3,0x9d,0xb,0x89,0x24,0xdf,0x3c,0xb0,
  0xf,0xf1,0xfc,0x31,0x5e,0x72,0xf5,0xb2,0xa6,0x79,0x2b,0xc3,0xa3,0x11,0x28,0x25,
  0xbc,0xcf,0xa8,0xfb,0x56,0x11,0x51,0x0,0x54,0xe8,0xe3,0xf7,0xa4,0xf1,0xe0,0x4e,
  0x65,0xf,0x40,0xd5,0x54,0x3f,0xa3,0xec,0x2b,0x32,0xb0,0xe3,0xd5,0x2a,0x2c,0xaf,
  0xb6,0xa8,0x6b,0xd6,0x11,0xf5,0xfd,0x37,0xe7,0xe4,0x9e,0x58,0x1,0x50,0x86,0x88,
  0x20,0x3e,0x35,0x8d,0x2f,0x7a,0x7a,0x50,0xea,0x2f,0xa5,0xc7,0x53,0x84,0x92,0x95,
  0x7e,0xe4,0x17,0x39,0x70,0xf4,0xdd,0x53,0xb2,0x12,0xe,0x9c,0x1d,0xed,0xc5,0x4f,
  0xe7,0x7,0xe1,0x59,0x70,0xb0,0xcc,0x5f,0xe,0xa4,0x1,0x65,0x28,0x50,0x13,0x96,
  0xd6,0x96,0xd6,0xb7,0x5b,0xf6,0xbe,0x42,0x47,0x81,0x5d,0x46,0xc7,0xee,0xa0,0xfb,
  0x70,0xb7,0xc4,0x52,0x71,0x54,0xd4,0xac,0x13,0x6b,0xdf,0x10,0x36,0x5b,0x52,0x52,
  0x38,0x12,0xc1,0xaa,0x81,0x5c,0xc9,0xbd,0xb5,0xc,0x3f,0xcc,0xf,0xc8,0xc1,0xae,
  0x43,0xf0,0xe6,0x78,0xa5,0x6c,0x75,0x39,0x8c,0x2f,0x4f,0x9e,0xc6,0xd8,0xea,0x4b,
  0x68,0x7a,0xbd,0x16,0x3e,0x3c,0x8a,0x6c,0x1f,0xd0,0xd5,0x71,0x4,0x2d,0x49,0xa0,
  0xd3,0x9a,0x5,0x26,0xb2,0x80,0x21,0x2d,0xc8,0x74,0xc0,0xf2,0xb8,0x45,0x7e,0x2d,
  0x99,0x43,0xeb,0x23,0xc3,0x68,0xb,0xb5,0xa3,0xba,0x2a,0x8,0x43,0x59,0xc,0xdc,
  0x18,0x19,0x93,0xfd,0x3f,0xbe,0x86,0x65,0x89,0x62,0x6c,0xc,0x6c,0xc1,0xa7,0xc1,
  0x80,0xf8,0x6,0x6f,0x60,0x2e,0xd3,0xc0,0xef,0xce,0x59,0xf4,0xf4,0xff,0xc3,0xa6,
  0xc7,0x8a,0xc4,0x7b,0xed,0x3f,0xac,0xb9,0x9e,0x87,0x4e,0x4f,0x99,0x5c,0xdd,0xf2,
  0x14,0x54,0x16,0x80,0x58,0x34,0xae,0x83,0xbb,0x82,0xa6,0xbb,0x2e,0x93,0xd9,0xcf,
  0x81,0x4f,0xd7,0x7a,0x38,0xbe,0xb6,0x94,0x23,0x6b,0x1f,0xe2,0xc2,0x85,0xcd,0x9c,
  0x1e,0x77,0xea,0xfd,0x7b,0x1e,0x34,0x7,0x1f,0xf6,0xf1,0xb6,0xd5,0xc6,0x5b,0x4e,
  0x7,0xc7,0xd7,0x95,0x73,0xfe,0xc2,0x45,0x92,0xa4,0x90,0xd4,0x0,0x64,0x67,0xdd,
  0x4b,0xbc,0xf2,0xed,0xd7,0x68,0x2b,0x76,0x4a,0xb5,0x99,0xc2,0x60,0xa9,0x15,0x81,
  0x43,0x37,0x19,0x1b,0x74,0xa1,0xe0,0x70,0xae,0xd8,0xfe,0x8e,0x22,0x1a,0xf0,0x62,
  0xda,0x9d,0xd,0xef,0x2f,0xa3,0xe8,0x2d,0x5f,0x8e,0xe0,0xf1,0x33,0x4b,0x3,0xa1,
  0xf7,0x43,0xe0,0x27,0x5d,0xac,0xf7,0xfa,0xa1,0x23,0x37,0x95,0x61,0x33,0xb0,0x2f,
  0x3e,0xc7,0xac,0x8d,0x64,0x67,0xd8,0xa9,0x9c,0xb1,0x59,0x44,0xf2,0x6c,0x38,0xdd,
  0x55,0xac,0xed,0x97,0xa7,0xe5,0xc5,0x8f,0xe2,0x72,0x34,0x67,0x92,0x52,0xbd,0x97,
  0x86,0x6,0x70,0xb9,0xaf,0xf,0x55,0x91,0x3b,0xea,0xaf,0x58,0x1c,0x13,0x85,0xe,
  0x6c,0xcb,0xb3,0xe1,0xe5,0xd,0x2b,0xc4,0x99,0xd4,0x52,0x60,0x8d,0x62,0xbc,0x28,
  0x1f,0x4d,0xb7,0x27,0x31,0x1c,0x1a,0x52,0x6f,0xd8,0x57,0xc1,0xe2,0xca,0x45,0x2,
  0xe,0x71,0x66,0x18,0x62,0x28,0x0,0x1d,0x1f,0x84,0xd0,0x11,0x9,0xc3,0x6d,0xb5,
  0x31,0x19,0x9d,0xc1,0x56,0x77,0x9e,0x54,0xb8,0xdc,0x58,0xbc,0x1b,0xc7,0x1f,0x54,
  0xf8,0xea,0x80,0x8d,0x33,0xe7,0x93,0xb2,0xe9,0x58,0x39,0x5f,0xa8,0x28,0x10,0xba,
  0x88,0xa9,0x19,0x1b,0xdb,0x76,0x37,0x42,0xb4,0xa9,0xb5,0x2c,0xa5,0xa9,0xae,0x5c,
  0x1f,0x65,0xdb,0xb1,0x7a,0x69,0xb4,0x67,0x61,0x7b,0xcc,0xd,0x8b,0x98,0x38,0x73,
  0x75,0x1c,0x3,0x4f,0xdc,0xa5,0x5f,0x3b,0xe4,0xf9,0x29,0x1f,0xb2,0xd3,0x26,0x86,
  0x72,0xfc,0x58,0xf3,0xd6,0x3b,0x70,0xb8,0x72,0x69,0x0,0x80,0x36,0x35,0x94,0x45,
  0x61,0xf2,0xcf,0x61,0xfc,0x36,0xf1,0x33,0x16,0x6a,0x5d,0xfc,0xf7,0xac,0x4f,0x76,
  0xe4,0x7,0x10,0xac,0x5c,0x8f,0xaa,0x94,0x16,0xa5,0x34,0xcc,0x7,0xe6,0x31,0x5b,
  0xbc,0x1,0xeb,0x77,0x37,0x33,0x3b,0xd7,0x2e,0xa6,0x69,0x2,0x4c,0x9b,0x5a,0xa7,
  0x4d,0x4d,0xad,0x99,0x4a,0xa4,0xf4,0xf6,0xba,0x6d,0xc4,0x26,0x68,0x94,0x81,0x7b,
  0x2a,0x9f,0x64,0xf8,0xf3,0xe3,0xfc,0xae,0xbd,0x99,0x1f,0x3e,0x5b,0xc9,0x73,0x5d,
  0x47,0x34,0x49,0x9a,0x8b,0x69,0x6d,0xa6,0x16,0xa9,0xd3,0xa6,0x16,0x9d,0xd6,0x1a,
  0x20,0x9,0x28,0x65,0x51,0x8c,0x47,0xe3,0x72,0xf2,0xb3,0x53,0x9c,0x4f,0x26,0xa4,
  0xbe,0xa1,0x1,0x85,0x9e,0xc2,0xa5,0xe7,0x11,0xa,0x2,0xea,0xb4,0x29,0xa2,0x14,
  0x41,0x2d,0x0,0xf8,0x3f,0xf3,0x74,0xa7,0xb4,0x1a,0x14,0x6f,0xd7,0x0,0x0,0x0,
  0x0,0x49,0x45,0x4e,0x44,0xae,0x42,0x60,0x82,
  
};

static const unsigned char qt_resource_name[] = {
  // icons
  0x0,0x5,
  0x0,0x6f,0xa6,0x53,
  0x0,0x69,
  0x0,0x63,0x0,0x6f,0x0,0x6e,0x0,0x73,
    // icqdie.png
  0x0,0xa,
  0xa,0xfd,0xa3,0xa7,
  0x0,0x69,
  0x0,0x63,0x0,0x71,0x0,0x64,0x0,0x69,0x0,0x65,0x0,0x2e,0x0,0x70,0x0,0x6e,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x90,0xad,0x23,0x5b,0xb0,
  // :/icons
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x90,0xad,0x23,0x5b,0xb0,
  // :/icons/icqdie.png
  0x0,0x0,0x0,0x10,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x90,0xad,0x23,0x5b,0xb0,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_resources)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_resources)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_resources)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_resources)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_resources)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_resources)(); }
   } dummy;
}
